@@ -8,11 +8,12 @@ mod exec;
 mod export;
 mod help;
 mod ignorer;
-mod internal;
 mod jobs;
 mod mission;
 mod result;
 mod search;
+#[cfg(unix)]
+mod socket;
 mod sound;
 mod tty;
 mod tui;
@@ -28,7 +29,6 @@ pub use {
     export::*,
     help::*,
     ignorer::*,
-    internal::*,
     jobs::*,
     mission::*,
     result::*,
@@ -39,5 +39,8 @@ pub use {
     watcher::*,
 };
 
+#[cfg(unix)]
+pub use socket::*;
+
 #[macro_use]
 extern crate cli_log;
