@@ -1,7 +1,10 @@
 mod command_output;
 mod command_result;
 mod failure;
+mod filter;
+mod items;
 mod line;
+mod location;
 mod report;
 mod report_maker;
 mod wrapped_command_output;
@@ -11,7 +14,10 @@ pub use {
     command_output::*,
     command_result::*,
     failure::*,
+    filter::*,
+    items::*,
     line::*,
+    location::*,
     report::*,
     report_maker::*,
     wrapped_command_output::*,
