@@ -3,7 +3,7 @@ mod tline_builder;
 mod trange;
 mod tstring;
 
-pub const CSI_RESET: &str = "\u{1b}[0m\u{1b}[0m";
+pub const CSI_RESET: &str = "\u{1b}[0m";
 pub const CSI_BOLD: &str = "\u{1b}[1m";
 pub const CSI_ITALIC: &str = "\u{1b}[3m";
 
@@ -12,6 +12,7 @@ pub const CSI_GREEN: &str = "\u{1b}[32m";
 pub const CSI_RED: &str = "\u{1b}[31m";
 pub const CSI_BOLD_RED: &str = "\u{1b}[1m\u{1b}[38;5;9m";
 pub const CSI_BOLD_ORANGE: &str = "\u{1b}[1m\u{1b}[38;5;208m";
+pub const CSI_BOLD_GREEN: &str = "\u{1b}[1m\u{1b}[38;5;34m";
 
 /// Used for "Blocking"
 pub const CSI_BLUE: &str = "\u{1b}[1m\u{1b}[36m";
@@ -53,9 +54,15 @@ pub fn draw(
     raw: &str,
 ) -> Result<()> {
     if csi.is_empty() {
-        write!(w, "{}", raw)?;
+        write!(w, "{raw}")?;
     } else {
-        write!(w, "{}{}{}", csi, raw, CSI_RESET,)?;
+        write!(w, "{csi}{raw}{CSI_RESET}")?;
     }
     Ok(())
 }
+pub fn csi(
+    fg: u8,
+    bg: u8,
+) -> String {
+    format!("\u{1b}[1m\u{1b}[38;5;{}m\u{1b}[48;5;{}m", fg, bg)
+}
